"""
Copyright (c) 2023, Magentix
This code is licensed under simplified BSD license (see LICENSE for details)
"""
requirement = []
try:
    import markdown
except ModuleNotFoundError:
    requirement.append('markdown module is required [pip install markdown]')


def file_content_opened(content: str, args: dict) -> str:
    """
    For the md extension, we convert the content from Markdown to HTML with Python markdown module
    """
    if not args['path'].endswith('.md'):
        return content
    if requirement:
        return ', '.join(requirement)
    return markdown.markdown(content, tab_length=2, extensions=_get_md_extensions())


def _get_md_extensions() -> list:
    """
    Markdown extensions to enable

    - fenced_code: https://python-markdown.github.io/extensions/fenced_code_blocks/
    - tables:      https://python-markdown.github.io/extensions/tables/
    - attr_list:   https://python-markdown.github.io/extensions/attr_list/
    - md_in_html:  https://python-markdown.github.io/extensions/md_in_html/
    - nl2br:       https://python-markdown.github.io/extensions/nl2br/
    """
    return ['fenced_code', 'tables', 'attr_list', 'md_in_html', 'nl2br']
