import data from '../fixtures/editor.json'

export class Action {
  static deletePage(pageData) {
    cy.visit(data.url.edit + pageData.path)
    cy.get('#i_title').invoke('val').then(($value) => {
      cy.get('[data-cy="delete"]').click()
      cy.on('window:confirm', () => true);
      if ($value) {
        cy.get('[data-cy="message-success"]')
          .should('be.visible')
          .contains(`Page "${pageData.path}" has been deleted`)
      } else {
        cy.get('[data-cy="message-error"]')
          .should('be.visible')
          .contains(`Page "${pageData.path}" does not exist`)
      }
    })
  }

  static addPage(pageData) {
    cy.visit(data.url.editor)
    cy.get('[data-cy="add"]').click()
    const fields = {
      "text": ["_full_path", "title"],
      "select": ["_page_type", "enabled", "tags"]
    }
    for (var i = 0; i < fields.text.length; i++) {
      cy.get('#i_' + fields.text[i]).type(pageData[fields.text[i]])
    }
    for (var j = 0; j < fields.select.length; j++) {
      cy.get('#i_' + fields.select[j]).select(pageData[fields.select[j]])
    }
    cy.get('.CodeMirror').click().type(pageData.content)
    cy.get('[data-cy="save"]').click()
    cy.get('[data-cy="message-success"]').should('be.visible').contains('The page has been saved')
  }

  static updatePage(pageData) {
    cy.intercept('POST', data.url.edit + pageData.path + '?ajax=1').as('ajax-save')
    cy.visit(data.url.edit + pageData.path)
    // Classic save when one or more fields are updated
    const fields = {
      'text': ['meta_title', 'meta_description'],
      'select': ['robots']
    }
    for (var i = 0; i < fields.text.length; i++) {
      cy.get('#i_' + fields.text[i]).type(pageData[fields.text[i]])
    }
    for (var j = 0; j < fields.select.length; j++) {
      cy.get('#i_' + fields.select[j]).select(pageData[fields.select[j]])
    }
    cy.get('[data-cy="save"]').click()
    cy.get('[data-cy="message-success"]').should('be.visible').contains('The page has been saved')

    // Save in Ajax when only the content has been updated
    cy.get('.CodeMirror').click().type(pageData.content)
    cy.get('[data-cy="save"]').click()
    cy.wait('@ajax-save').its('response.statusCode').should('eq', 200)
    cy.get('[data-cy="message-success"]').should('be.visible').contains('The page has been saved')
  }

  static viewPage(pageData) {
    cy.visit(data.url.edit + pageData.path)
    cy.get('[data-cy="view"]').invoke('removeAttr', 'target').click()
    cy.contains('Hello World')
  }
}

describe('Editor tests', () => {
  it('Delete pages', () => {
    Action.deletePage(data.pages.js)
    Action.deletePage(data.pages.html)
    Action.deletePage(data.pages.md)
  })

  it('Add pages', () => {
    Action.addPage(data.pages.js)
    Action.addPage(data.pages.html)
    Action.addPage(data.pages.md)
  })

  it('View pages', () => {
    Action.viewPage(data.pages.html)
    Action.viewPage(data.pages.md)

    cy.visit(data.url.edit + data.pages.html.path)
    cy.get('[data-cy="view"]').invoke('removeAttr', 'target').click()
    cy.on('window:alert', (str) => {
      expect(str).to.equal('Hello World')
    })
  })

  it('Update pages', () => {
    Action.updatePage(data.pages.html)
    Action.updatePage(data.pages.md)
  })

  it('Add pages', () => {
    Action.deletePage(data.pages.js)
    Action.deletePage(data.pages.html)
    Action.deletePage(data.pages.md)
  })
})
